

PREVIOUS_VERSION = '0.25.0' ### We need to change this to point to the next version


def main():
    print(PREVIOUS_VERSION)


if __name__ == "__main__":
    main()

